### Effects


### If this is a new feature or a bug fix ...
- [ ] Yes, the branch I'm proposing to merge is called `issue-xyz` where `xyz` is the number of the issue.

### If this change adds or modifies a validation case
- [ ] No.
- [ ] Yes and:
  - I have coded up, or updated, an existing test case; and
  - I have provided a GMAT script which confirms the result(s); and
  - I have updated the `VALIDATION.md` file with the new error data between nyx and GMAT.
  - I will specify the version of GMAT used for the validation.
